documentationtools.Pipe
=======================

.. inheritance-diagram:: abjad.tools.documentationtools.Pipe.Pipe.Pipe
   :private-bases:

.. autoclass:: abjad.tools.documentationtools.Pipe.Pipe.Pipe

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.arguments

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.executable

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.timeout

Methods
-------

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.close

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.communicate

    Inherited from :py:class:`subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.kill

    Inherited from :py:class:`subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.poll

    Inherited from :py:class:`subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.read

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.read_wait

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.send_signal

    Inherited from :py:class:`subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.terminate

    Inherited from :py:class:`subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.wait

    Inherited from :py:class:`subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.write

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.write_line

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__del__

    Inherited from :py:class:`subprocess.Popen`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
